==> rapid_widgets_library-0.2.42.tar.gz: lib/custom-webAppBar.dart <==
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget appbarWEB(AppBarParams appBarParams) {
  return Card(
    elevation: (appBarParams.elevation != null) ? appBarParams.elevation : 0,
    shadowColor: (appBarParams.shadowColor != null) ? appBarParams.shadowColor : Colors.transparent,
    color: (appBarParams.backgroundColor != null) ? appBarParams.backgroundColor : Colors.transparent,
    shape: RoundedRectangleBorder(
      borderRadius: BorderRadius.circular((appBarParams.bottomRadius != 0) ? appBarParams.bottomRadius : 0),
    ),
    child: Row(mainAxisAlignment: MainAxisAlignment.end, children: [
      SizedBox(
        width: 10,
      ),
      (appBarParams.imageUrl != 'null')
          ? Padding(
        padding: EdgeInsets.only(
          bottom: (appBarParams.bottomPadImage != 0) ? appBarParams.bottomPadImage : 0,
          top: (appBarParams.topPadImage != null) ? appBarParams.topPadImage : 0,
          left: (appBarParams.leftPadImage != null) ? appBarParams.leftPadImage : 0,
          right: (appBarParams.rightPadImage != null) ? appBarParams.rightPadImage : 0,
        ),
        child: Image(height: 40, image: NetworkImage(appBarParams.imageUrl)),
      )
          : SizedBox.shrink(),
      SizedBox(
        width: 10,
      ),
      (appBarParams.text != 'null')
          ? Text(
        appBarParams.text,
        style: TextStyle(color: appBarParams.textColor, fontSize: 12),
      )
          : SizedBox.shrink(),
      SizedBox(
        width: 10,
      ),
      (appBarParams.icon1 != null)
          ? Icon(appBarParams.icon1, size: 15, color: appBarParams.iconColor)
          : SizedBox.shrink(),
      SizedBox(
        width: 10,
      ),
      (appBarParams.icon2 != null)
          ? Icon(appBarParams.icon2, size: 15, color: appBarParams.iconColor)
          : SizedBox.shrink(),
      SizedBox(
        width: 10,
      ),
      (appBarParams.icon3 != null)
          ? Icon(appBarParams.icon3, size: 15, color: appBarParams.iconColor)
          : SizedBox.shrink(),
    ]),
  );
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/custom-webAppBar.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget appbarWEB(AppBarParams appBarParams) {
  return Card(
    elevation: (appBarParams.elevation != null) ? appBarParams.elevation : 0,
    shadowColor: (appBarParams.shadowColor != null) ? appBarParams.shadowColor : Colors.transparent,
    color: (appBarParams.backgroundColor != null) ? appBarParams.backgroundColor : Colors.transparent,
    shape: RoundedRectangleBorder(
      borderRadius: BorderRadius.circular((appBarParams.bottomRadius != 0) ? appBarParams.bottomRadius : 0),
    ),
    child: Row(mainAxisAlignment: MainAxisAlignment.end, children: [
      SizedBox(
        width: 10,
      ),
      (appBarParams.imageUrl != 'null')
          ? Padding(
        padding: EdgeInsets.only(
          bottom: (appBarParams.bottomPadImage != 0) ? appBarParams.bottomPadImage : 0,
          top: (appBarParams.topPadImage != null) ? appBarParams.topPadImage : 0,
          left: (appBarParams.leftPadImage != null) ? appBarParams.leftPadImage : 0,
          right: (appBarParams.rightPadImage != null) ? appBarParams.rightPadImage : 0,
        ),
        child: Image(height: 40, image: NetworkImage(appBarParams.imageUrl)),
      )
          : SizedBox.shrink(),
      SizedBox(
        width: 10,
      ),
      (appBarParams.text != 'null')
          ? Text(
        appBarParams.text,
        style: GoogleFonts.getFont('Roboto',color: appBarParams.textColor, fontSize: 12),
      )
          : SizedBox.shrink(),
      SizedBox(
        width: 10,
      ),
      (appBarParams.icon1 != null)
          ? Icon(appBarParams.icon1, size: 15, color: appBarParams.iconColor)
          : SizedBox.shrink(),
      SizedBox(
        width: 10,
      ),
      (appBarParams.icon2 != null)
          ? Icon(appBarParams.icon2, size: 15, color: appBarParams.iconColor)
          : SizedBox.shrink(),
      SizedBox(
        width: 10,
      ),
      (appBarParams.icon3 != null)
          ? Icon(appBarParams.icon3, size: 15, color: appBarParams.iconColor)
          : SizedBox.shrink(),
    ]),
  );
}
